@@ -1,4 +1,4 @@
-/* --< GKrellShoot 0.4.3 >--{ 19 November 2004 }--
+/* --< GKrellShoot 0.4.4 >--{ 8 December 2006 }--
  * Ported to Gkrellm2.0
  *
  * Author: M.R.Muthu Kumar (m_muthukumar@users.sourceforge.net)
@@ -19,7 +19,8 @@
 
 #include<math.h>
 
-#define GKRELLSHOOT_VER 	"0.4.3"
+#define GKRELLSHOOT_VER 	"0.4.4"
+#define GKRELLSHOOT_YEAR 	"2006"
 #define DEFAULT_XLOCK		"xscreensaver-command -lock"
 #define SHOOT_SCREEN		"import -window root"
 #define SHOOT_WINDOW		"import"
@@ -54,6 +55,15 @@
 #define MIN_PANELS	0
 #define NUM_COLORS 32
 
+#define MAX_F_FORMAT	6	/*Maximum filename formats */
+
+#define MMDDYY		"MM-DD-YY"
+#define MMDDYYYY	"MM-DD-YYYY"
+#define YYMMDD		"YY-MM-DD"
+#define YYYYMMDD	"YYYY-MM-DD"
+#define DDMMYY		"DD-MM-YY"
+#define DDMMYYYY	"DD-MM-YYYY"
+
 #define SELECT_BOTH	0
 #define SELECT_LOCK	1
 #define SELECT_SHOOT	2
@@ -62,6 +72,7 @@ static gchar *anim_name[] = { B_BALL, MESH, RADAR, SINE, STAR, RAIN, R_LINE,
                               C_BOARD, SCANNER, C_BAR, R_STAR };
 static gint  current_anim[MAX_PANELS];
 static gint  cycle_anim[MAX_PANELS];
+static gchar *ff_name[] = { MMDDYY, MMDDYYYY, YYMMDD, YYYYMMDD, DDMMYY, DDMMYYYY };
 
 static GkrellmMonitor		*mon;
 static GkrellmChart		*chart[MAX_PANELS];
@@ -84,6 +95,7 @@ static gchar xlock_cmd[513];
 static gchar view_cmd[513];
 static gchar save_dir[513];
 static gchar image_format[32];
+static gchar ff_select[32];
 static gchar shoot_cmd[1024];
 static gint  lock_shoot_select = SELECT_BOTH;
 
@@ -101,6 +113,7 @@ static GtkWidget	*wait_seconds_option,
                         *image_format_option,
                         *window_option,
                         *anim_select_option[MAX_PANELS],
+                        *ff_select_option,
                         *num_panel_option,
                         *cycle_anim_option[MAX_PANELS],
                         *view_image_option,
@@ -1343,7 +1356,7 @@ update_plugin ()
     {
 	  if ( cycle_anim[i] > 0 ) { update_cycle_anim( i ); }
 
-      gtk_signal_emit_by_name(GTK_OBJECT(chart[i]->drawing_area),
+      g_signal_emit_by_name(GTK_OBJECT(chart[i]->drawing_area),
                                 "expose_event", &event, &ret_val  );
     }
 }
@@ -1406,10 +1419,37 @@ run_shoot_cmd()
 
   tm = gkrellm_get_current_time();
 
+if ( ! strcmp( ff_select, YYMMDD ) ) {
+  sprintf( filename, "%s/gkrellShoot_%02d-%02d-%02d_%02d%02d%02d.%s", 
+		  save_dir,
+		  tm->tm_year-100, tm->tm_mon+1, tm->tm_mday, tm->tm_hour, 
+		  tm->tm_min, tm->tm_sec, image_format );
+} else  if ( ! strcmp( ff_select, YYYYMMDD ) ) {
+  sprintf( filename, "%s/gkrellShoot_%02d-%02d-%02d_%02d%02d%02d.%s", 
+		  save_dir,
+		  tm->tm_year+1900, tm->tm_mon+1, tm->tm_mday, tm->tm_hour, 
+		  tm->tm_min, tm->tm_sec, image_format );
+} else  if ( ! strcmp( ff_select, DDMMYY ) ) {
+  sprintf( filename, "%s/gkrellShoot_%02d-%02d-%02d_%02d%02d%02d.%s", 
+		  save_dir,
+		  tm->tm_mday, tm->tm_mon+1,  tm->tm_year-100, tm->tm_hour, 
+		  tm->tm_min, tm->tm_sec, image_format );
+} else  if ( ! strcmp( ff_select, DDMMYYYY ) ) {
+  sprintf( filename, "%s/gkrellShoot_%02d-%02d-%02d_%02d%02d%02d.%s", 
+		  save_dir,
+		  tm->tm_mday, tm->tm_mon+1,  tm->tm_year+1900, tm->tm_hour, 
+		  tm->tm_min, tm->tm_sec, image_format );
+} else  if ( ! strcmp( ff_select, MMDDYYYY ) ) {
+  sprintf( filename, "%s/gkrellShoot_%02d-%02d-%02d_%02d%02d%02d.%s", 
+		  save_dir,
+		  tm->tm_mon+1, tm->tm_mday, tm->tm_year+1900, tm->tm_hour, 
+		  tm->tm_min, tm->tm_sec, image_format );
+} else {
   sprintf( filename, "%s/gkrellShoot_%02d-%02d-%02d_%02d%02d%02d.%s", 
 		  save_dir,
 		  tm->tm_mon+1, tm->tm_mday, tm->tm_year-100, tm->tm_hour, 
 		  tm->tm_min, tm->tm_sec, image_format );
+}
 
   
   make_shoot_cmd();
@@ -1591,21 +1631,21 @@ create_plugin(GtkWidget *vbox, gint first_create)
 	{	
         for ( i = 0; i < 3; i++ )
         {
-	    gtk_signal_connect(GTK_OBJECT (panel[i]->drawing_area), "expose_event",
-    	         (GtkSignalFunc) expose_event, GINT_TO_POINTER(i));
+	    g_signal_connect(GTK_OBJECT (panel[i]->drawing_area), "expose_event",
+    	         G_CALLBACK( expose_event ), GINT_TO_POINTER(i));
 
-	    gtk_signal_connect(GTK_OBJECT (panel[i]->drawing_area), 
+	    g_signal_connect(GTK_OBJECT (panel[i]->drawing_area), 
 	 	         "button_press_event",
-    	         (GtkSignalFunc) panel_press, NULL);
+    	         G_CALLBACK( panel_press ), NULL);
         }
 
         for ( i = 0; i < MAX_PANELS; i++ )
 		{
-	      gtk_signal_connect(GTK_OBJECT (chart[i]->drawing_area), "expose_event",
-    	        (GtkSignalFunc) chart_expose_event, GINT_TO_POINTER(i) );
-	      gtk_signal_connect(GTK_OBJECT (chart[i]->drawing_area), 
+	      g_signal_connect(GTK_OBJECT (chart[i]->drawing_area), "expose_event",
+    	        G_CALLBACK ( chart_expose_event ), GINT_TO_POINTER(i) );
+	      g_signal_connect(GTK_OBJECT (chart[i]->drawing_area), 
 	        "button_press_event",
-    	        (GtkSignalFunc) anim_chart_press, GINT_TO_POINTER(i));
+    	        G_CALLBACK ( anim_chart_press ), GINT_TO_POINTER(i));
 		}
 
 	    gdk_rgb_init();
@@ -1643,6 +1683,7 @@ save_shoot_config (FILE *f)
             with_frame);
     fprintf(f, "%s grayscale %d\n", PLUGIN_CONFIG_KEYWORD, grayscale );
     fprintf(f, "%s save_dir %s\n", PLUGIN_CONFIG_KEYWORD, save_dir);
+    fprintf(f, "%s ff_select %s\n", PLUGIN_CONFIG_KEYWORD, ff_select);
     fprintf(f, "%s lock_shoot_select %d\n", PLUGIN_CONFIG_KEYWORD,
             lock_shoot_select);
 
@@ -1721,10 +1762,10 @@ load_shoot_config (gchar *arg)
             sscanf(item, "%d\n", &(with_frame));
  	if (strcmp(config, "grayscale") == 0)
  	    sscanf(item, "%d\n", &(grayscale));
-        if (strcmp(config, "save_dir") == 0)
-	    {	
-              strcpy(save_dir, item);
-	    }    
+        if (strcmp(config, "save_dir") == 0) {	strcpy(save_dir, item); }    
+
+        if (strcmp(config, "ff_select") == 0) {	strcpy(ff_select, item); }    
+
         if (strcmp(config, "lock_shoot_select") == 0)
             sscanf(item, "%d\n", &(lock_shoot_select));
     }
@@ -1791,6 +1832,9 @@ apply_shoot_config (void)
       }
     }
 
+    c = gkrellm_gtk_entry_get_text(&(GTK_COMBO(ff_select_option)->entry));
+     if (strcmp(ff_select, c) ) { strcpy( ff_select, c ); } 
+
 }
 static GtkWidget *create_anim_config_tab( gint i )
 {
@@ -1923,45 +1967,47 @@ static void
 create_shoot_tab (GtkWidget *tab)
 {
     GtkWidget *frame, *ybox, *hbox, *vbox, *separator, 
-              *label, *text, *info_window, *about_label;
+              *label, *text, *about_label;
     GtkAdjustment *wait_adjust, *num_panel_adjust;
 
     GtkWidget *tablabel, *anim_config, *button;
 	gchar *anim_tab_name;
 
-    gint i;
+    GList *items = NULL;
+
+    gint i, j;
 
 
     gchar *about_text = NULL;
     static gchar *help_text[] =
     {
-      "<b>" CONFIG_NAME " " GKRELLSHOOT_VER "\n\n" ,
-      "Grabs screen/window when Shoot is clicked (uses ImageMagick 5.5.7 or greater) \n" ,
-      "Locks the screen when Lock is clicked. And optionally will display " ,
-      "Animation. \n\n" ,
-      "<b> Options \n\n" ,
-      "Save Location - valid path to save images when shoot is clicked.\n",
-      "Lock/Shoot Select - choose the button to be displayed .\n",
-      "Image Format - any valid image format supported by ImageMagick.\n",
-      "Maximum of 3 animation panels are possible.Each can have its\n",
-      "own animation. To Disable animation choose 0.\n\n",
-      "<b> Animation Panel \n\n" ,
-      "Select Animation from dropdown. To cycle through animation choose\n",
-      "number of minutes between cycle.\n",
-      "Middle-click the Animation to cycle through all available animations.\n",
-      "Right-click to open config window .\n\n",
-      "<i> Usage \n\n" ,
-      "Once Shoot is clicked if window grab is selected then cross prompt \n",
-      "appears on the screen using which one can select a window\n",
-      "by clicking on a window or hold down mouse and choose an area \n",
-      "to be grabbed, otherwise whole screen is grabbed. If with window \n",
-      "frame is selected, windows are grabbed with their frame. \n",
-      "If grayscale is selected you get grayscaled image. \n",
-      "Grabbed image is saved on to the directory specified in \n",
-      "Save Location with the following name : \n",
-      "gkrellShoot_MM-DD-YY_HHMMSS.imageFormat(jpg,gif etc). \n\n",
-      "If View Image is selected Grabbed Image is passed onto given ",
-      "Image Viewer. "
+      N_("<h>" CONFIG_NAME " " GKRELLSHOOT_VER "\n\n" ),
+      N_("Grabs screen/window when Shoot is clicked (uses ImageMagick 5.5.7 or greater) \n" ),
+      N_("Locks the screen when Lock is clicked. And optionally will display " ),
+      N_("Animation. \n\n" ),
+      N_("<b> Options \n\n" ),
+      N_("Save Location - valid path to save images when shoot is clicked.\n"),
+      N_("Date Format - select data format to append to filename .\n"),
+      N_("Lock/Shoot Select - choose the button to be displayed .\n"),
+      N_("Image Format - any valid image format supported by ImageMagick.\n"),
+      N_("Maximum of 3 animation panels are possible.Each can have its\n"),
+      N_("own animation. To Disable animation choose 0.\n\n"),
+      N_("<b> Animation Panel \n\n" ),
+      N_("Select Animation from dropdown. To cycle through animation choose\n"),
+      N_("number of minutes between cycle.\n"),
+      N_("Middle-click the Animation to cycle through all available animations.\n"),
+      N_("Right-click to open config window .\n\n"),
+      N_("<b> Usage \n\n" ),
+      N_("Once Shoot is clicked if window grab is selected then cross prompt \n"),
+      N_("appears on the screen using which one can select a window\n"),
+      N_("by clicking on a window or hold down mouse and choose an area \n"),
+      N_("to be grabbed, otherwise whole screen is grabbed. \n\n "),
+      N_("If with window frame is selected, windows are grabbed with their frame. \n\n"),
+      N_("If grayscale is selected you get grayscaled image. \n\n"),
+      N_("Grabbed image is saved on to the directory specified in Save Location with the\n"),
+      N_("name gkrellShoot_<Date Format Option>_HHMMSS.imageFormat(jpg,gif etc). \n\n"),
+      N_("If View Image is selected Grabbed Image is passed onto given "),
+      N_("Image Viewer. ")
     };
 
 	if ( laptop ) { gtk_object_unref( GTK_OBJECT( laptop ) ); }
@@ -2001,10 +2047,28 @@ create_shoot_tab (GtkWidget *tab)
 
     gtk_container_add(GTK_CONTAINER(vbox), hbox);
 
-    separator = gtk_hseparator_new();
-    gtk_box_pack_start(GTK_BOX(vbox), separator, FALSE, FALSE, 4);
+
+    /* Date Format to append to filename */
+    hbox = gtk_hbox_new(FALSE, 0);
+    label = gtk_label_new("Date Format( to append to filename) " );
+
+    for ( j = 0; j < MAX_F_FORMAT; j++ )
+    {
+      items = g_list_append (items, ff_name[j] );
+    }
+    ff_select_option = gtk_combo_new();
+    gtk_combo_set_popdown_strings (GTK_COMBO (ff_select_option), items);
+    gtk_combo_set_value_in_list( GTK_COMBO(ff_select_option), TRUE, FALSE );
+    gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(ff_select_option)->entry), ff_select );
+
+    gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(hbox), ff_select_option, FALSE, FALSE, 0);
+
+    gtk_container_add(GTK_CONTAINER(vbox), hbox);
 
     /* Lock_Shoot Select */
+    separator = gtk_hseparator_new();
+    gtk_box_pack_start(GTK_BOX(vbox), separator, FALSE, FALSE, 4);
 
      ybox = gkrellm_gtk_framed_vbox(vbox, _("Lock/Shoot Select"),
                         4, FALSE, 0, 2);
@@ -2128,33 +2192,23 @@ create_shoot_tab (GtkWidget *tab)
 	  }	
     }
         /* help */
-    frame = gtk_frame_new(NULL);
-    gtk_container_border_width(GTK_CONTAINER(frame), 3);
-    info_window = gtk_scrolled_window_new(NULL, NULL);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(info_window),
-    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    gtk_container_add(GTK_CONTAINER(frame), info_window);
-
-    text = gtk_text_view_new();
-
-    gkrellm_gtk_text_view_append_strings(text, help_text, sizeof(help_text)/sizeof(gchar*));
-    gtk_text_view_set_editable(GTK_TEXT_VIEW(text), FALSE);
-    gtk_container_add(GTK_CONTAINER(info_window), text);
-
-    label = gtk_label_new("Help");
-    gtk_notebook_append_page(GTK_NOTEBOOK(laptop), frame, label);
+	vbox = gkrellm_gtk_framed_notebook_page(laptop, _("Help"));
+	text = gkrellm_gtk_scrolled_text_view(vbox, NULL,
+				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	for (i = 0; i < sizeof(help_text)/sizeof(gchar *); ++i)
+		gkrellm_gtk_text_view_append(text, _(help_text[i]));
 
         /* about */
     about_text = g_strdup_printf(
         "GKrellShoot %s\n" \
         "GKrellM Shoot Plugin\n" \
         "\n" \
-        "Copyright (C) 2004 M.R.Muthu Kumar\n" \
+        "Copyright (C) %s M.R.Muthu Kumar\n" \
         "m_muthukumar@users.sourceforge.net\n" \
         "\n" \
         "Released under the GNU Public License\n" \
 	"GkrellShoot comes with ABSOLUTELY NO WARRANTY\n" \
-        , GKRELLSHOOT_VER
+        , GKRELLSHOOT_VER, GKRELLSHOOT_YEAR
     );
     about_label = gtk_label_new(about_text);
     g_free(about_text);
@@ -2217,6 +2271,8 @@ read_default(void)
 
    sprintf( filename, "%s/%s", save_dir, DEFAULT_OUTFILE );
 
+   sprintf( ff_select,"%s",  MMDDYY );
+
    gk_ticks = gkrellm_ticks();
 }	
 
@@ -2225,7 +2281,7 @@ read_default(void)
   |  which returns a pointer to a filled in monitor structure.
   */
 GkrellmMonitor *
-gkrellm_init_plugin()
+gkrellm_init_plugin( void )
 	{
 	/* If this call is made, the background and krell images for this plugin
 	|  can be custom themed by putting bg_meter.png or krell.png in the
